/*******************************************************************************
* File Name: Cnt_Src.h
* Version 1.50
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_Cnt_Src_H)
#define CY_CLOCK_Cnt_Src_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/

void Cnt_Src_Start(void) ;
void Cnt_Src_Stop(void) ;

#if(!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2) && \
	!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 && \
	CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_ES1))
void Cnt_Src_StopBlock(void) ;
#endif

void Cnt_Src_StandbyPower(uint8 state) ;
void Cnt_Src_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 Cnt_Src_GetDividerRegister(void) ;
void Cnt_Src_SetModeRegister(uint8 modeBitMask) ;
void Cnt_Src_ClearModeRegister(uint8 modeBitMask) ;
uint8 Cnt_Src_GetModeRegister(void) ;
void Cnt_Src_SetSourceRegister(uint8 clkSource) ;
uint8 Cnt_Src_GetSourceRegister(void) ;
#if defined(Cnt_Src__CFG3)
void Cnt_Src_SetPhaseRegister(uint8 clkPhase) ;
uint8 Cnt_Src_GetPhaseRegister(void) ;
#endif

#define Cnt_Src_Enable()                       Cnt_Src_Start()
#define Cnt_Src_Disable()                      Cnt_Src_Stop()
#define Cnt_Src_SetDivider(clkDivider)         Cnt_Src_SetDividerRegister(clkDivider, 1)
#define Cnt_Src_SetDividerValue(clkDivider)    Cnt_Src_SetDividerRegister((clkDivider) - 1, 1)
#define Cnt_Src_SetMode(clkMode)               Cnt_Src_SetModeRegister(clkMode)
#define Cnt_Src_SetSource(clkSource)           Cnt_Src_SetSourceRegister(clkSource)
#if defined(Cnt_Src__CFG3)
#define Cnt_Src_SetPhase(clkPhase)             Cnt_Src_SetPhaseRegister(clkPhase)
#define Cnt_Src_SetPhaseValue(clkPhase)        Cnt_Src_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*           API Constants
***************************************/

/* Constants SetPhase(), clkPhase parameter. Only valid for PSoC 3 ES2 and earlier. See datasheet for details. */
#if CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
   (CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES1 || \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2)
#define CYCLK_2_5NS             0x01 /* 2.5 ns delay. */
#define CYCLK_3_5NS             0x02 /* 3.5 ns delay. */
#define CYCLK_4_5NS             0x03 /* 4.5 ns delay. */
#define CYCLK_5_5NS             0x04 /* 5.5 ns delay. */
#define CYCLK_6_5NS             0x05 /* 6.5 ns delay. */
#define CYCLK_7_5NS             0x06 /* 7.5 ns delay. */
#define CYCLK_8_5NS             0x07 /* 8.5 ns delay. */
#define CYCLK_9_5NS             0x08 /* 9.5 ns delay. */
#define CYCLK_10_5NS            0x09 /* 10.5 ns delay. */
#define CYCLK_11_5NS            0x0A /* 11.5 ns delay. */
#define CYCLK_12_5NS            0x0B /* 12.5 ns delay. */
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define Cnt_Src_CLKEN              (* (reg8 *) Cnt_Src__PM_ACT_CFG)
#define Cnt_Src_CLKEN_PTR          ((reg8 *) Cnt_Src__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define Cnt_Src_CLKSTBY            (* (reg8 *) Cnt_Src__PM_STBY_CFG)
#define Cnt_Src_CLKSTBY_PTR        ((reg8 *) Cnt_Src__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define Cnt_Src_DIV_LSB            (* (reg8 *) Cnt_Src__CFG0)
#define Cnt_Src_DIV_LSB_PTR        ((reg8 *) Cnt_Src__CFG0)
#define Cnt_Src_DIV_PTR            ((reg16 *) Cnt_Src__CFG0)

/* Clock MSB divider configuration register. */
#define Cnt_Src_DIV_MSB            (* (reg8 *) Cnt_Src__CFG1)
#define Cnt_Src_DIV_MSB_PTR        ((reg8 *) Cnt_Src__CFG1)

/* Mode and source configuration register */
#define Cnt_Src_MOD_SRC            (* (reg8 *) Cnt_Src__CFG2)
#define Cnt_Src_MOD_SRC_PTR        ((reg8 *) Cnt_Src__CFG2)

#if defined(Cnt_Src__CFG3)
/* Analog clock phase configuration register */
#define Cnt_Src_PHASE              (* (reg8 *) Cnt_Src__CFG3)
#define Cnt_Src_PHASE_PTR          ((reg8 *) Cnt_Src__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define Cnt_Src_CLKEN_MASK         Cnt_Src__PM_ACT_MSK
#define Cnt_Src_CLKSTBY_MASK       Cnt_Src__PM_STBY_MSK

/* CFG2 field masks */
#define Cnt_Src_SRC_SEL_MSK        Cnt_Src__CFG2_SRC_SEL_MASK
#define Cnt_Src_MODE_MASK          (~(Cnt_Src_SRC_SEL_MSK))

#if defined(Cnt_Src__CFG3)
/* CFG3 phase mask */
#define Cnt_Src_PHASE_MASK         Cnt_Src__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_Cnt_Src_H */


/* [] END OF FILE */
