/*******************************************************************************
* File Name: Cnt_ISR.c  
* Version 1.50
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <Cnt_ISR.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START Cnt_ISR_intc` */

/* `#END` */


/*******************************************************************************
* Function Name: Cnt_ISR_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void Cnt_ISR_Start(void)
{
    /* For all we know the interrupt is active. */
    Cnt_ISR_Disable();

    /* Set the ISR to point to the Cnt_ISR Interrupt. */
    Cnt_ISR_SetVector(Cnt_ISR_Interrupt);

    /* Set the priority. */
    Cnt_ISR_SetPriority(Cnt_ISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    Cnt_ISR_Enable();
}

/*******************************************************************************
* Function Name: Cnt_ISR_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void Cnt_ISR_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    Cnt_ISR_Disable();

    /* Set the ISR to point to the Cnt_ISR Interrupt. */
    Cnt_ISR_SetVector(address);

    /* Set the priority. */
    Cnt_ISR_SetPriority(Cnt_ISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    Cnt_ISR_Enable();
}

/*******************************************************************************
* Function Name: Cnt_ISR_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void Cnt_ISR_Stop(void) 
{
    /* Disable this interrupt. */
    Cnt_ISR_Disable();
}

/*******************************************************************************
* Function Name: Cnt_ISR_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for Cnt_ISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(Cnt_ISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START Cnt_ISR_Interrupt` */
	gCnt_Status_Reg = Counter_ReadStatusRegister();
	if(bCnt_OverFlow)
	{
		//Counter_Stop();
		Counter_ClearFIFO();
		nCap_Cnt = 0;
	}
	else if(bCnt_Cap)
	{
		nCap_Cnt++;
		if(nCap_Cnt == 1)
		{
			//Counter_WriteCounter(0);
			//Counter_Enable();
			nCap_Val[0] = Counter_ReadCapture();
			
		}
		else if(nCap_Cnt == 2)
		{
			nCap_Val[1] = Counter_ReadCapture();
			
			nPeriod = nCap_Val[1] -nCap_Val[0];
			nCap_Val[0] = 0;
			nCap_Val[1] = 0;	
			flag = 1;
		}
	}

    /* `#END` */

    /* PSoC3 ES1, ES2 RTC ISR PATCH  */ 
    #if(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3)
        #if((CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2) && (Cnt_ISR__ES2_PATCH ))      
            Cnt_ISR_ISR_PATCH();
        #endif
    #endif
}

/*******************************************************************************
* Function Name: Cnt_ISR_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling Cnt_ISR_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use Cnt_ISR_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Cnt_ISR_SetVector(cyisraddress address) 
{
    CY_SET_REG16(Cnt_ISR_INTC_VECTOR, (uint16) address);
}

/*******************************************************************************
* Function Name: Cnt_ISR_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress Cnt_ISR_GetVector(void) 
{
    return (cyisraddress) CY_GET_REG16(Cnt_ISR_INTC_VECTOR);
}

/*******************************************************************************
* Function Name: Cnt_ISR_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling Cnt_ISR_Start
*   or Cnt_ISR_StartEx will override any effect this method would have had. 
*	This method should only be called after Cnt_ISR_Start or 
*	Cnt_ISR_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Cnt_ISR_SetPriority(uint8 priority) 
{
    *Cnt_ISR_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: Cnt_ISR_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 Cnt_ISR_GetPriority(void) 
{
    uint8 priority;


    priority = *Cnt_ISR_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: Cnt_ISR_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Cnt_ISR_Enable(void) 
{
    /* Enable the general interrupt. */
    *Cnt_ISR_INTC_SET_EN = Cnt_ISR__INTC_MASK;
}

/*******************************************************************************
* Function Name: Cnt_ISR_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 Cnt_ISR_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*Cnt_ISR_INTC_SET_EN & Cnt_ISR__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: Cnt_ISR_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Cnt_ISR_Disable(void) 
{
    /* Disable the general interrupt. */
    *Cnt_ISR_INTC_CLR_EN = Cnt_ISR__INTC_MASK;
}

/*******************************************************************************
* Function Name: Cnt_ISR_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Cnt_ISR_SetPending(void) 
{
    *Cnt_ISR_INTC_SET_PD = Cnt_ISR__INTC_MASK;
}

/*******************************************************************************
* Function Name: Cnt_ISR_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void Cnt_ISR_ClearPending(void) 
{
    *Cnt_ISR_INTC_CLR_PD = Cnt_ISR__INTC_MASK;
}
